@@ -173,6 +173,8 @@ cps_plot <- function(spct,
 #'   than all other elements within a window of width span centered at that
 #'   element.
 #' @param annotations a character vector ("summaries" is ignored)
+#' @param time.format character Format as accepted by \code{\link[base]{strptime}}.
+#' @param tz character Time zone to use for title and/or subtitle.
 #' @param norm numeric normalization wavelength (nm) or character string "max"
 #'   for normalization at the wavelength of highest peak.
 #' @param text.size numeric size of text in the plot decorations.
@@ -196,6 +198,8 @@ plot.cps_spct <-
            label.qty = "mean",
            span = NULL,
            annotations = NULL,
+           time.format = "",
+           tz = "UTC",
            norm = NULL,
            text.size = 2.5,
            na.rm = TRUE) {
@@ -214,18 +218,19 @@ plot.cps_spct <-
       }
     }
 
-    out.ggplot <- cps_plot(spct = x, w.band = w.band, range = range,
-                           label.qty = label.qty,
-                           span = span,
-                           pc.out = pc.out,
-                           annotations = annotations, norm = norm,
-                           text.size = text.size,
-                           na.rm = na.rm,
-                           ...)
-    if ("title" %in% annotations) {
-      out.ggplot <- out.ggplot + labs(title = deparse(substitute(x)))
-    }
-    out.ggplot
+    cps_plot(spct = x, w.band = w.band, range = range,
+             label.qty = label.qty,
+             span = span,
+             pc.out = pc.out,
+             annotations = annotations, norm = norm,
+             text.size = text.size,
+             na.rm = na.rm,
+             ...) +
+      ggtitle_spct(x = x,
+                   time.format = time.format,
+                   tz = tz,
+                   x.name = deparse(substitute(x)),
+                   annotations = annotations)
   }
 
 
