@@ -798,6 +798,8 @@ O_plot <- function(spct,
 #'   than all other elements within a window of width span centered at that
 #'   element.
 #' @param annotations a character vector
+#' @param time.format character Format as accepted by \code{\link[base]{strptime}}.
+#' @param tz character Time zone to use for title and/or subtitle.
 #' @param text.size numeric size of text in the plot decorations.
 #' @param na.rm logical.
 #'
@@ -824,6 +826,8 @@ plot.filter_spct <-
            label.qty = NULL,
            span = NULL,
            annotations = NULL,
+           time.format = "",
+           tz = "UTC",
            text.size = 2.5,
            na.rm = TRUE) {
     annotations.default <-
@@ -883,10 +887,12 @@ plot.filter_spct <-
     } else {
       stop("Invalid 'plot.qty' argument value: '", plot.qty, "'")
     }
-    if ("title" %in% annotations) {
-      out.ggplot <- out.ggplot + labs(title = deparse(substitute(x)))
-    }
-    out.ggplot
+    out.ggplot +
+      ggtitle_spct(x = x,
+                   time.format = time.format,
+                   tz = tz,
+                   x.name = deparse(substitute(x)),
+                   annotations = annotations)
   }
 
 #' Plot method for reflector spectra.
@@ -913,6 +919,8 @@ plot.filter_spct <-
 #'   than all other elements within a window of width span centered at that
 #'   element.
 #' @param annotations a character vector
+#' @param time.format character Format as accepted by \code{\link[base]{strptime}}.
+#' @param tz character Time zone to use for title and/or subtitle.
 #' @param text.size numeric size of text in the plot decorations.
 #' @param na.rm logical.
 #'
@@ -939,6 +947,8 @@ plot.reflector_spct <-
            label.qty = NULL,
            span = NULL,
            annotations = NULL,
+           time.format = "",
+           tz = "UTC",
            text.size = 2.5,
            na.rm = TRUE) {
     annotations.default <-
@@ -976,10 +986,12 @@ plot.reflector_spct <-
     } else {
       stop("Invalid 'plot.qty' argument value: '", plot.qty, "'")
     }
-    if ("title" %in% annotations) {
-      out.ggplot <- out.ggplot + labs(title = deparse(substitute(x)))
-    }
-    out.ggplot
+    out.ggplot +
+      ggtitle_spct(x = x,
+                   time.format = time.format,
+                   tz = tz,
+                   x.name = deparse(substitute(x)),
+                   annotations = annotations)
   }
 
 
@@ -1008,6 +1020,8 @@ plot.reflector_spct <-
 #'   than all other elements within a window of width span centered at that
 #'   element.
 #' @param annotations a character vector
+#' @param time.format character Format as accepted by \code{\link[base]{strptime}}.
+#' @param tz character Time zone to use for title and/or subtitle.
 #' @param stacked logical
 #' @param text.size numeric size of text in the plot decorations.
 #' @param na.rm logical.
@@ -1035,6 +1049,8 @@ plot.object_spct <-
            label.qty = NULL,
            span = 61,
            annotations = NULL,
+           time.format = "",
+           tz = "UTC",
            stacked = TRUE,
            text.size = 2.5,
            na.rm = TRUE) {
@@ -1121,8 +1137,10 @@ plot.object_spct <-
     } else {
       stop("Invalid 'plot.qty' argument value: '", plot.qty, "'")
     }
-    if ("title" %in% annotations) {
-      out.ggplot <- out.ggplot + labs(title = deparse(substitute(x)))
-    }
-    out.ggplot
+    out.ggplot +
+      ggtitle_spct(x = x,
+                   time.format = time.format,
+                   tz = tz,
+                   x.name = deparse(substitute(x)),
+                   annotations = annotations)
   }
